@@ -1,6 +1,6 @@
 /* -*- C -*- 
   mboxgrep - scan mailbox for messages matching a regular expression
-  Copyright (C) 2000, 2001  Daniel Spiljar
+  Copyright (C) 2000, 2001, 2002  Daniel Spiljar
 
   Mboxgrep is free software; you can redistribute it and/or modify it 
   under the terms of the GNU General Public License as published by
@@ -16,17 +16,35 @@
   along with mboxgrep; if not, write to the Free Software Foundation, 
   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-  $Id: mh.h,v 1.1 2001/10/26 13:05:01 dspiljar Exp $ */
+  $Id: mh.h,v 1.4 2002/02/06 22:10:44 dspiljar Exp $ */
 
 #ifndef MH_H
 #define MH_H 1
 
-#include <dirent.h>      /* for DIR structure */
+#include <config.h>
+
+#ifdef HAVE_DIRENT_H
+# include <dirent.h>
+# define NAMLEN(dirent) strlen((dirent)->d_name)
+#else
+# define dirent direct
+# define NAMLEN(dirent) (dirent)->d_namlen
+# ifdef HAVE_SYS_NDIR_H
+#  include <sys/ndir.h>
+# endif /* HAVE_SYS_NDIR_H */
+# ifdef HAVE_SYS_DIR_H
+#  include <sys/dir.h>
+# endif /* HAVE_SYS_DIR_H */
+# ifdef HAVE_NDIR_H
+#  include <ndir.h>
+# endif /* HAVE_NDIR_H */
+#endif /* HAVE_DIRENT_H */
+
 #include "mboxgrep.h"
 
-DIR *mh_open(const char *path);
-void mh_close(DIR *dp);
-message_t *mh_read_message(DIR *dp);
-void mh_write_message(message_t *m, const char *path);
+DIR *mh_open (const char *path);
+void mh_close (DIR *dp);
+message_t *mh_read_message (DIR *dp);
+void mh_write_message (message_t *m, const char *path);
 
 #endif /* MH_H */
