@@ -1,6 +1,6 @@
 /* -*- C -*- 
   mboxgrep - scan mailbox for messages matching a regular expression
-  Copyright (C) 2000, 2001  Daniel Spiljar
+  Copyright (C) 2000, 2001, 2002  Daniel Spiljar
 
   Mboxgrep is free software; you can redistribute it and/or modify it 
   under the terms of the GNU General Public License as published by
@@ -16,14 +16,14 @@
   along with mboxgrep; if not, write to the Free Software Foundation, 
   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-  $Id: scan.h,v 1.3 2001/12/01 23:35:55 dspiljar Exp $ */
+  $Id: scan.h,v 1.5 2002/01/19 14:58:11 dspiljar Exp $ */
 
 #ifndef SCAN_H
 #define SCAN_H 1
 
 #include "mboxgrep.h"
 
-void scan_mailbox (char path[], format_t format);
+void scan_mailbox (char path[]);
 int md5_check_message (char *body, checksum_t *chksum);
 
 #endif /* SCAN_H */
