@@ -1,6 +1,6 @@
 /* -*- C -*- 
   mboxgrep - scan mailbox for messages matching a regular expression
-  Copyright (C) 2000, 2001  Daniel Spiljar
+  Copyright (C) 2000, 2001, 2002  Daniel Spiljar
 
   Mboxgrep is free software; you can redistribute it and/or modify it 
   under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
   along with mboxgrep; if not, write to the Free Software Foundation, 
   Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-  $Id: wrap.h,v 1.3 2001/12/02 17:27:02 dspiljar Exp $ */
+  $Id: wrap.h,v 1.7 2002/01/19 14:58:11 dspiljar Exp $ */
 
 /* This file is part of mboxgrep. */
 
@@ -25,21 +25,42 @@
 #ifndef WRAP_H
 #define WRAP_H
 
+#include <config.h>
 #include <stdio.h>
+#include <sys/types.h>
+
+#ifdef HAVE_DIRENT_H
+# include <dirent.h>
+# define NAMLEN(dirent) strlen((dirent)->d_name)
+#else
+# define dirent direct
+# define NAMLEN(dirent) (dirent)->d_namlen
+# ifdef HAVE_SYS_NDIR_H
+#  include <sys/ndir.h>
+# endif /* HAVE_SYS_NDIR_H */
+# ifdef HAVE_SYS_DIR_H
+#  include <sys/dir.h>
+# endif /* HAVE_SYS_DIR_H */
+# ifdef HAVE_NDIR_H
+#  include <ndir.h>
+# endif /* HAVE_NDIR_H */
+#endif /* HAVE_DIRENT_H */
+
 #include <stdlib.h>
-#include <dirent.h>
 
-int m_open(const char *pathname, int flags, mode_t mode);
+int m_open (const char *pathname, int flags, mode_t mode);
 
-FILE *m_fopen(const char *path, const char *mode);
-FILE *m_fdopen(int fildes, const char *mode);
+FILE *m_fopen (const char *path, const char *mode);
+FILE *m_fdopen (int fildes, const char *mode);
 
-DIR *m_opendir(const char *name);
+DIR *m_opendir (const char *name);
 
-void *xmalloc(size_t size);
-void *xrealloc(void *ptr, size_t size);
-void *xcalloc(size_t nmemb, size_t size);
+void *xmalloc (size_t size);
+void *xrealloc (void *ptr, size_t size);
+void *xcalloc (size_t nmemb, size_t size);
 
-int m_unlink(const char *pathname);
+char *xstrdup (const char *s);
+
+int m_unlink (const char *pathname);
 
 #endif /* WRAP_H */
